==> nextcloud-24.0.9.tgz: nextcloud/apps/files_versions/l10n/zh_HK.js <==
OC.L10N.register(
    "files_versions",
    {
    "Versions" : "版本",
    "This application automatically maintains older versions of files that are changed." : "本應用程式會自動保存修改前舊版本的檔案",
    "This application automatically maintains older versions of files that are changed. When enabled, a hidden versions folder is provisioned in every user's directory and is used to store old file versions. A user can revert to an older version through the web interface at any time, with the replaced file becoming a version. The app automatically manages the versions folder to ensure the user does not run out of Quota because of versions.\n\t\tIn addition to the expiry of versions, the versions app makes certain never to use more than 50% of the user's currently available free space. If stored versions exceed this limit, the app will delete the oldest versions first until it meets this limit. More information is available in the Versions documentation." : "此應用程式會自動維護已變更過檔案的較舊版本。啟用後，每個用戶目錄中都會有一個隱藏的版本資料夾，此資料夾用於儲存較舊版本的檔案。用戶可以在任何時候透過網路界面還原到較舊的版本，取代目前版本成為新的版本。應用程式會自動管理版本資料夾以確保用戶不會因為版本而用完配額。\n\t\t除了版本有效期限以外，版本應用程式還會確保用戶永遠不會使用超過用戶目前可用空間的 50%。如果儲存的版本超出此限制，則應用程式會先刪除最舊的版本，直到低於此限制。更多資訊請見「版本」文件。",
    "Download version" : "下載版本",
    "Restore version" : "還原版本",
    "No versions yet" : "尚無版本",
    "Version restored" : "版本已還原",
    "Could not restore version" : "無法還原版本",
    "Version" : "版本",
    "This application automatically maintains older versions of files that are changed. When enabled, a hidden versions folder is provisioned in every user’s directory and is used to store old file versions. A user can revert to an older version through the web interface at any time, with the replaced file becoming a version. The app automatically manages the versions folder to ensure the user doesn’t run out of Quota because of versions.\n\t\tIn addition to the expiry of versions, the versions app makes certain never to use more than 50% of the user’s currently available free space. If stored versions exceed this limit, the app will delete the oldest versions first until it meets this limit. More information is available in the Versions documentation." : "此應用程式會自動維護已變更過檔案的較舊版本。啟用後，每個用戶目錄中都會有一個隱藏的版本資料夾，此資料夾用於儲存較舊版本的檔案。用戶可以在任何時候透過網路界面還原到較舊的版本，取代目前版本成為新的版本。應用程式會自動管理版本資料夾以確保用戶不會因為版本而用完配額。\n\t\t除了版本有效期限以外，版本應用程式還會確保用戶永遠不會使用超過用戶目前可用空間的 50%。如果儲存的版本超出此限制，則應用程式會先刪除最舊的版本，直到低於此限制。更多資訊請見「版本」文件。",
    "Failed to revert {file} to revision {timestamp}." : "無法還原檔案 {file} 至版本 {timestamp}",
    "_%n byte_::_%n bytes_" : ["%n bytes"],
    "Restore" : "復原",
    "No other versions available" : "沒有其他版本了"
},
"nplurals=1; plural=0;");

==> nextcloud-24.0.11p0.tgz: nextcloud/apps/files_versions/l10n/zh_HK.js <==
OC.L10N.register(
    "files_versions",
    {
    "Versions" : "版本",
    "This application automatically maintains older versions of files that are changed." : "本應用程式會自動保存修改前舊版本的檔案",
    "This application automatically maintains older versions of files that are changed. When enabled, a hidden versions folder is provisioned in every user's directory and is used to store old file versions. A user can revert to an older version through the web interface at any time, with the replaced file becoming a version. The app automatically manages the versions folder to ensure the user does not run out of Quota because of versions.\n\t\tIn addition to the expiry of versions, the versions app makes certain never to use more than 50% of the user's currently available free space. If stored versions exceed this limit, the app will delete the oldest versions first until it meets this limit. More information is available in the Versions documentation." : "此應用程式會自動維護已變更過檔案的較舊版本。啟用後，每個用戶目錄中都會有一個隱藏的版本資料夾，此資料夾用於儲存較舊版本的檔案。用戶可以在任何時候透過網路界面還原到較舊的版本，取代目前版本成為新的版本。應用程式會自動管理版本資料夾以確保用戶不會因為版本而用完配額。\n\t\t除了版本有效期限以外，版本應用程式還會確保用戶永遠不會使用超過用戶目前可用空間的 50%。如果儲存的版本超出此限制，則應用程式會先刪除最舊的版本，直到低於此限制。更多資訊請見「版本」文件。",
    "Name this version" : "為此版本命名",
    "Edit version name" : "編輯版本名稱",
    "Restore version" : "還原版本",
    "Download version" : "下載版本",
    "Delete version" : "刪除版本",
    "Version name" : "版本名稱",
    "Named versions are persisted, and excluded from automatic cleanups when your storage quota is full." : "命名版本會保留，並在儲存配額已滿時從自動清理中排除。",
    "Remove version name" : "移除版本名稱",
    "Save version name" : "儲存版本名稱",
    "Initial version restored" : "初始版本已還原",
    "Version restored" : "版本已還原",
    "Could not restore version" : "無法還原版本",
    "Could not set version name" : "無法設定版本名稱",
    "Could not delete version" : "無法刪除版本",
    "${version.label} restored" : "已還原˙ ${version.label}",
    "This application automatically maintains older versions of files that are changed. When enabled, a hidden versions folder is provisioned in every user’s directory and is used to store old file versions. A user can revert to an older version through the web interface at any time, with the replaced file becoming a version. The app automatically manages the versions folder to ensure the user doesn’t run out of Quota because of versions.\n\t\tIn addition to the expiry of versions, the versions app makes certain never to use more than 50% of the user’s currently available free space. If stored versions exceed this limit, the app will delete the oldest versions first until it meets this limit. More information is available in the Versions documentation." : "此應用程式會自動維護已變更過檔案的較舊版本。啟用後，每個用戶目錄中都會有一個隱藏的版本資料夾，此資料夾用於儲存較舊版本的檔案。用戶可以在任何時候透過網路界面還原到較舊的版本，取代目前版本成為新的版本。應用程式會自動管理版本資料夾以確保用戶不會因為版本而用完配額。\n\t\t除了版本有效期限以外，版本應用程式還會確保用戶永遠不會使用超過用戶目前可用空間的 50%。如果儲存的版本超出此限制，則應用程式會先刪除最舊的版本，直到低於此限制。更多資訊請見「版本」文件。",
    "Failed to revert {file} to revision {timestamp}." : "無法還原檔案 {file} 至版本 {timestamp}",
    "_%n byte_::_%n bytes_" : ["%n bytes"],
    "Restore" : "復原",
    "No other versions available" : "沒有其他版本了"
},
"nplurals=1; plural=0;");
